searchData={"items":[{"type":"module","title":"RaRegistry","doc":"A distributed registry for Elixir GenServers using Ra (RabbitMQ's Raft implementation).\n\nRaRegistry provides similar functionality to Elixir's built-in Registry module,\nbut with distributed consensus via Ra, making it suitable for distributed\napplications across multiple nodes.\n\nIt supports both :unique and :duplicate registration modes.","ref":"RaRegistry.html"},{"type":"module","title":"Usage - RaRegistry","doc":"```elixir\n# Register a process with a unique key\nRaRegistry.register(:my_registry, \"unique_key\", :some_value)\n\n# Look up a process by key\nRaRegistry.lookup(:my_registry, \"unique_key\")\n\n# Register with a duplicate key\nRaRegistry.register(:my_duplicate_registry, \"shared_key\", :value1)\nRaRegistry.register(:my_duplicate_registry, \"shared_key\", :value2)\n\n# Look up all processes with the duplicate key\nRaRegistry.lookup(:my_duplicate_registry, \"shared_key\")\n```","ref":"RaRegistry.html#module-usage"},{"type":"module","title":"Via Registration - RaRegistry","doc":"You can also use RaRegistry as a process registry with GenServer and other OTP processes\nby using the `:via` tuple:\n\n```elixir\n# Start a GenServer with RaRegistry\nname = {:via, RaRegistry, {MyRegistry, \"my_server\"}}\n{:ok, pid} = GenServer.start_link(MyServer, arg, name: name)\n\n# Call the server using the same via tuple\nGenServer.call(name, :some_request)\n```","ref":"RaRegistry.html#module-via-registration"},{"type":"function","title":"RaRegistry.child_spec/1","doc":"See `start_link/2` for options.","ref":"RaRegistry.html#child_spec/1"},{"type":"function","title":"RaRegistry.count/2","doc":"Returns the number of processes registered under the given key.","ref":"RaRegistry.html#count/2"},{"type":"function","title":"Examples - RaRegistry.count/2","doc":"RaRegistry.count(MyRegistry, \"key\")","ref":"RaRegistry.html#count/2-examples"},{"type":"function","title":"RaRegistry.keys/1","doc":"Returns the registry key type, either :unique or :duplicate.","ref":"RaRegistry.html#keys/1"},{"type":"function","title":"RaRegistry.lookup/2","doc":"Looks up the given key in the registry and returns the associated processes.","ref":"RaRegistry.html#lookup/2"},{"type":"function","title":"Examples - RaRegistry.lookup/2","doc":"RaRegistry.lookup(MyRegistry, \"key\")","ref":"RaRegistry.html#lookup/2-examples"},{"type":"function","title":"RaRegistry.register/4","doc":"Registers the given process under the given key in the registry.\nIf no pid is provided, registers the current process.","ref":"RaRegistry.html#register/4"},{"type":"function","title":"Examples - RaRegistry.register/4","doc":"RaRegistry.register(MyRegistry, \"key\", :value)\n    RaRegistry.register(MyRegistry, \"key\", :value, other_pid)","ref":"RaRegistry.html#register/4-examples"},{"type":"function","title":"RaRegistry.register_name/2","doc":"Implementation for the `:via` registration mechanism.\nRegisters the current process under the given `key` in the registry `name`.\nReturns `:yes` if registration succeeds, `:no` otherwise.","ref":"RaRegistry.html#register_name/2"},{"type":"function","title":"RaRegistry.send/2","doc":"Implementation for the `:via` registration mechanism.\nSends a message to the process registered under the given `key` in `registry`.","ref":"RaRegistry.html#send/2"},{"type":"function","title":"RaRegistry.start_link/1","doc":"Starts a new registry with the given name and options.","ref":"RaRegistry.html#start_link/1"},{"type":"function","title":"Options - RaRegistry.start_link/1","doc":"* `:keys` - The kind of keys in this registry. Can be either `:unique` or `:duplicate` (required).\n* `:name` - A local or global name for the registry (required).","ref":"RaRegistry.html#start_link/1-options"},{"type":"function","title":"Examples - RaRegistry.start_link/1","doc":"RaRegistry.start_link(keys: :unique, name: MyRegistry)\n    RaRegistry.start_link(keys: :duplicate, name: {MyRegistry, self()})","ref":"RaRegistry.html#start_link/1-examples"},{"type":"function","title":"RaRegistry.unregister/3","doc":"Unregisters the current process for the given key in the registry.","ref":"RaRegistry.html#unregister/3"},{"type":"function","title":"Examples - RaRegistry.unregister/3","doc":"RaRegistry.unregister(MyRegistry, \"key\")","ref":"RaRegistry.html#unregister/3-examples"},{"type":"function","title":"RaRegistry.unregister_name/1","doc":"Implementation for the `:via` registration mechanism.\nUnregisters the given `key` from the registry `name`.","ref":"RaRegistry.html#unregister_name/1"},{"type":"function","title":"RaRegistry.update_value/3","doc":"Updates the value associated with the key for the current process.","ref":"RaRegistry.html#update_value/3"},{"type":"function","title":"Examples - RaRegistry.update_value/3","doc":"RaRegistry.update_value(MyRegistry, \"key\", fn value -> value + 1 end)","ref":"RaRegistry.html#update_value/3-examples"},{"type":"function","title":"RaRegistry.whereis_name/1","doc":"Implementation for the `:via` registration mechanism.\nReturns the pid associated with the given `key` in the registry `name`.\nReturns `pid` if successful, `:undefined` otherwise.","ref":"RaRegistry.html#whereis_name/1"},{"type":"module","title":"RaRegistry.Manager","doc":"Manages the Ra cluster for the distributed registry.","ref":"RaRegistry.Manager.html"},{"type":"function","title":"RaRegistry.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"RaRegistry.Manager.html#child_spec/1"},{"type":"function","title":"RaRegistry.Manager.get_members/1","doc":"Returns the current members of the Ra cluster.","ref":"RaRegistry.Manager.html#get_members/1"},{"type":"function","title":"RaRegistry.Manager.start_link/1","doc":"","ref":"RaRegistry.Manager.html#start_link/1"},{"type":"module","title":"RaRegistry.StateMachine","doc":"The Ra state machine implementation for the distributed registry.","ref":"RaRegistry.StateMachine.html"},{"type":"function","title":"RaRegistry.StateMachine.apply/3","doc":"","ref":"RaRegistry.StateMachine.html#apply/3"},{"type":"function","title":"RaRegistry.StateMachine.command_handler/3","doc":"Apply commands to the state machine.","ref":"RaRegistry.StateMachine.html#command_handler/3"},{"type":"function","title":"RaRegistry.StateMachine.handle_down/3","doc":"Handle process monitors.","ref":"RaRegistry.StateMachine.html#handle_down/3"},{"type":"function","title":"RaRegistry.StateMachine.init/1","doc":"Initialize the state machine with empty registry maps.","ref":"RaRegistry.StateMachine.html#init/1"},{"type":"function","title":"RaRegistry.StateMachine.lookup_query_duplicate/2","doc":"","ref":"RaRegistry.StateMachine.html#lookup_query_duplicate/2"},{"type":"function","title":"RaRegistry.StateMachine.lookup_query_unique/2","doc":"Query functions for Ra's consistent_query.\nThese must follow the proper format of receiving machine state as a single argument.","ref":"RaRegistry.StateMachine.html#lookup_query_unique/2"},{"type":"function","title":"RaRegistry.StateMachine.machine_config/0","doc":"Returns the Ra state machine configuration.","ref":"RaRegistry.StateMachine.html#machine_config/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}